@@ -8,6 +8,7 @@ from argparse import ArgumentParser
 import os
 import sys
 import time
+import shutil
 from fireworks.core.fw_config import FWConfig
 from fireworks.core.fworker import FWorker
 from fireworks.core.launchpad import LaunchPad
@@ -51,6 +52,36 @@ def do_launch(args):
         launch_rocket_to_queue(launchpad, fworker, queueadapter,
                                args.launch_dir, args.reserve, args.loglvl)
 
+def do_cleanup(args):
+
+    lp = LaunchPad.from_file(
+        args.launchpad_file) if args.launchpad_file else LaunchPad(
+        strm_lvl=args.loglvl)
+    to_delete = []
+    for i in lp.get_fw_ids({}):
+        fw = lp.get_fw_by_id(i)
+        if fw.state == "COMPLETED":
+            for l in fw.launches:
+                if os.path.isdir(l.launch_dir):
+                    to_delete.append((fw.fw_name, fw.fw_id,
+                                      l.launch_dir, os.listdir(l.launch_dir)))
+    if len(to_delete) == 0:
+        print "Your directories are clean!"
+        sys.exit(0)
+    print "The following will be deleted:"
+    for name, fwid, d, files in to_delete:
+        print "{}-{} - {} - {}".format(name, fwid, d, ", ".join(files))
+    ans = raw_input("Confirm? (Y/N)")
+    if ans.startswith("Y"):
+        for name, fwid, d, files in to_delete:
+            try:
+                shutil.rmtree(d)
+                print "Deleted {}".format(d)
+            except Exception as ex:
+                print "Unable to delete {} because of {}".format(d, ex)
+    else:
+        print "Canceled!"
+
 
 def qlaunch():
     m_description = 'This program is used to submit jobs to a queueing system. Details of the job and queue \
@@ -64,6 +95,9 @@ def qlaunch():
     single_parser = subparsers.add_parser('singleshot', help='launch a single rocket to the queue')
     rapid_parser = subparsers.add_parser('rapidfire', help='launch multiple rockets to the queue')
 
+    cleanup_parser = subparsers.add_parser('cleanup',
+                                           help='Cleanup the queue.')
+
     parser.add_argument("-rh", "--remote_host", nargs="*",
                         help="Remote host to exec qlaunch. Right now, "
                              "only supports running from a config dir.")
@@ -140,7 +174,7 @@ def qlaunch():
                                 put(f, os.path.join(r, f))
     non_default = []
     for k in ["maxjobs_queue", "maxjobs_block", "nlaunches", "sleep"]:
-        v = getattr(args, k)
+        v = getattr(args, k, None)
         if v != rapid_parser.get_default(k):
             non_default.append("--{} {}".format(k, v))
     non_default = " ".join(non_default)
@@ -156,7 +190,10 @@ def qlaunch():
                             run("qlaunch {} {}".format(args.command, non_default))
             disconnect_all()
         else:
-            do_launch(args)
+            if args.command != "cleanup":
+                do_launch(args)
+            else:
+                do_cleanup(args)
         if interval > 0:
             print "Next run in {} seconds... Press Ctrl-C to exit at any time." \
                 .format(interval)
